@@ -157,7 +157,7 @@ void AtlanticDesigner::initToken()
 		m_player = new Player(0);
 	else
 		m_player->setLocation(0);
-	
+
 	board->addToken(m_player);
 
 	connect(m_player, SIGNAL(changed(Player *)), board, SLOT(playerChanged(Player *)));
@@ -211,7 +211,7 @@ bool AtlanticDesigner::warnClose()
 {
 	if (isMod)
 	{
-		int result = KMessageBox::warningYesNoCancel(this, i18n("There are unsaved changes to gameboard. Save them?"), i18n("Unsaved Changes"), i18n("Save"), i18n("Discard"), "DiscardAsk", true);
+		int result = KMessageBox::warningYesNoCancel(this, i18n("There are unsaved changes to gameboard. Save them?"), i18n("Unsaved Changes"), KStdGuiItem::save(), KStdGuiItem::discard(), "DiscardAsk", true);
 		switch(result)
 		{
 		case KMessageBox::Yes:
@@ -511,7 +511,7 @@ void AtlanticDesigner::openFile(const QString &filename)
 					break;
 				}
 			}
-			
+
 			if (found)
 				continue;
 
@@ -639,7 +639,7 @@ void AtlanticDesigner::save()
 	{
 		if (estate->go())
 		{
-			t << "go=" << estate->estateId() << endl;
+			t << "go=" << estate->id() << endl;
 			hasGo = true;
 			break;
 		}
@@ -698,7 +698,7 @@ void AtlanticDesigner::save()
 	}
 
 	// now do the cards
-	
+
 	for (QValueList<CardStack>::Iterator it = cards.begin(); it != cards.end(); ++it)
 	{
 		t << endl << endl;
@@ -737,7 +737,7 @@ void AtlanticDesigner::save()
 				{
 					t << "canbeowned=" << 1 << endl;
 				}
-				
+
 				t << key << "=" << value << endl;
 			}
 		}
@@ -864,7 +864,7 @@ void AtlanticDesigner::changeEstate(Estate *estate)
 
 void AtlanticDesigner::movePlayer(Estate *estate)
 {
-	estateAct->setCurrentItem(estate->estateId());
+	estateAct->setCurrentItem(estate->id());
 	board->setFocus();
 	m_player->setLocation(estate);
 	m_player->update();
@@ -970,7 +970,7 @@ void AtlanticDesigner::goChanged(int id)
 {
 	ConfigEstate *curEstate = 0;
 	for (curEstate = estates.first(); curEstate; curEstate = estates.next())
-		if (curEstate->go() && curEstate->estateId() != id)
+		if (curEstate->go() && curEstate->id() != id)
 			curEstate->setGo(false);
 }
 
@@ -1034,7 +1034,7 @@ void AtlanticDesigner::up()
 	if (editor->upArrow())
 		return;
 	int fourth = max / 4;
-	int estateId = editor->theEstate()->estateId() + 1;
+	int estateId = editor->theEstate()->id() + 1;
 	int dest = estateId - 1;
 
 	if (estateId <= 2*fourth && estateId > fourth) // left side
@@ -1052,7 +1052,7 @@ void AtlanticDesigner::down()
 	if (editor->downArrow())
 		return;
 	int fourth = max / 4;
-	int estateId = editor->theEstate()->estateId() + 1;
+	int estateId = editor->theEstate()->id() + 1;
 	int dest = estateId - 1;
 
 	if (estateId <= (2*fourth + 1) && estateId > (fourth + 1)) // left side
@@ -1070,7 +1070,7 @@ void AtlanticDesigner::left()
 	if (editor->leftArrow())
 		return;
 	int fourth = max / 4;
-	int estateId = editor->theEstate()->estateId() + 1;
+	int estateId = editor->theEstate()->id() + 1;
 	int dest = estateId - 1;
 
 	if (estateId <= fourth) // bottom
@@ -1086,7 +1086,7 @@ void AtlanticDesigner::right()
 	if (editor->rightArrow())
 		return;
 	int fourth = max / 4;
-	int estateId = editor->theEstate()->estateId() + 1;
+	int estateId = editor->theEstate()->id() + 1;
 	int dest = estateId - 1;
 
 	if (estateId <= (fourth + 1) && estateId != 1) // bottom
