@@ -104,7 +104,7 @@ GroupEditor::GroupEditor(ConfigEstateGroupList *newList, QWidget *parent)
 void GroupEditor::add()
 {
 	bool ok;
-	QString name = KLineEditDlg::getText(i18n("Add Group"), i18n("Enter the name of the new group below:"), QString::null, &ok, this);
+	QString name = KLineEditDlg::getText(i18n("Add Group"), i18n("Enter the name of the new group:"), QString::null, &ok, this);
 	if (ok)
 	{
 		for (ConfigEstateGroupList::Iterator it =  mylist.begin(); it != mylist.end(); ++it)
