@@ -20,10 +20,14 @@
 
 #include <klineeditdlg.h>
 #include <kaction.h>
+#include <kinstance.h>
 #include <klocale.h>
 #include <cassert>
 #include <kdebug.h>
+#include <kgenericfactory.h>
        
+K_EXPORT_COMPONENT_FACTORY( katehtmltoolsplugin, KGenericFactory<PluginKateHtmlTools>( "katehtmltools" ) )
+
 class PluginView : public KXMLGUIClient
 {             
   friend class PluginKateHtmlTools;
@@ -32,33 +36,7 @@ class PluginView : public KXMLGUIClient
     Kate::MainWindow *win;
 };
 
-extern "C"
-{
-  void* init_katehtmltoolsplugin()
-  {
-    KGlobal::locale()->insertCatalogue("katehtmltools");
-    return new KatePluginFactory;
-  }
-}
-
-KatePluginFactory::KatePluginFactory()
-{
-  s_instance = new KInstance( "kate" );
-}
-
-KatePluginFactory::~KatePluginFactory()
-{
-  delete s_instance;
-}
-
-QObject* KatePluginFactory::createObject( QObject* parent, const char* name, const char*, const QStringList & )
-{
-  return new PluginKateHtmlTools( parent, name );
-}
-
-KInstance* KatePluginFactory::s_instance = 0L;
-
-PluginKateHtmlTools::PluginKateHtmlTools( QObject* parent, const char* name )
+PluginKateHtmlTools::PluginKateHtmlTools( QObject* parent, const char* name, const QStringList& )
     : Kate::Plugin ( (Kate::Application *)parent, name )
 {
 }
@@ -98,6 +76,9 @@ void PluginKateHtmlTools::removeView(Kate::MainWindow *win)
 void PluginKateHtmlTools::slotEditHTMLtag()
 //  PCP
 {
+  if (!application()->activeMainWindow())
+    return;
+
   Kate::View *kv=application()->activeMainWindow()->viewManager()->activeView();
   if (!kv) return;
 
