@@ -29,6 +29,10 @@
 
 #define POP_(x) kdDebug(13000) << #x " = " << flush << x << endl
 
+#include <kgenericfactory.h>
+       
+K_EXPORT_COMPONENT_FACTORY( katetextfilterplugin, KGenericFactory<PluginKateTextFilter>( "katetextfilter" ) )
+
 class PluginView : public KXMLGUIClient
 {
   friend class PluginKateTextFilter;
@@ -37,34 +41,7 @@ class PluginView : public KXMLGUIClient
     Kate::MainWindow *win;
 };
 
-extern "C"
-{
-  void* init_katetextfilterplugin()
-  {
-    KGlobal::locale()->insertCatalogue("katetextfilter");
-    return new KatePluginFactory;
-  }
-}
-
-KatePluginFactory::KatePluginFactory()
-{
-  s_instance = new KInstance( "kate" );
-}
-
-KatePluginFactory::~KatePluginFactory()
-{
-  delete s_instance;
-}
-
-QObject* KatePluginFactory::createObject( QObject* parent, const char* name, const char*, const QStringList & )
-{
-  return new PluginKateTextFilter( parent, name );
-}
-
-KInstance* KatePluginFactory::s_instance = 0L;
-
-
-PluginKateTextFilter::PluginKateTextFilter( QObject* parent, const char* name )
+PluginKateTextFilter::PluginKateTextFilter( QObject* parent, const char* name, const QStringList& )
     : Kate::Plugin ( (Kate::Application *)parent, name ),
   m_pFilterShellProcess (NULL)
 {
@@ -232,18 +209,15 @@ PluginKateTextFilter::slotFilterProcessExited (KProcess * pProcess)
         static void  //  PCP
 slipInFilter (KShellProcess & shell, Kate::View & view, QString command)
 {
-
   QString marked = view.getDoc()->selection ();
   if( marked.isEmpty())
       return;
 //  POP_(command.latin1 ());
   shell.clearArguments ();
-  shell << command.local8Bit ();
+  shell << command;
 
   shell.start (KProcess::NotifyOnExit, KProcess::All);
-
   shell.writeStdin (marked.local8Bit (), marked.length ());
-
   //  TODO: Put up a modal dialog to defend the text from further
   //  keystrokes while the command is out. With a cancel button...
 
@@ -261,6 +235,9 @@ PluginKateTextFilter::slotFilterCloseStdin (KProcess * pProcess)
                  void
 PluginKateTextFilter::slotEditFilter ()  //  PCP
 {
+  if (!application()->activeMainWindow())
+    return;
+
   Kate::View * kv (application()->activeMainWindow()->viewManager()->activeView());
   if (!kv) return;
 
