@@ -28,29 +28,14 @@
 #include <kate/mainwindow.h>
 #include <kate/viewmanager.h>
 
-#include <klibloader.h>
 #include <kprocess.h>
 
-class KatePluginFactory : public KLibFactory
-{
-  Q_OBJECT
-
-  public:
-    KatePluginFactory();
-    virtual ~KatePluginFactory();
-
-    virtual QObject* createObject( QObject* parent = 0, const char* pname = 0, const char* name = "QObject", const QStringList &args = QStringList() );
-
-  private:
-    static KInstance* s_instance;
-};
-
 class PluginKateTextFilter : public Kate::Plugin, Kate::PluginViewInterface
 {
   Q_OBJECT
 
   public:
-    PluginKateTextFilter( QObject* parent = 0, const char* name = 0 );
+    PluginKateTextFilter( QObject* parent = 0, const char* name = 0, const QStringList& = QStringList() );
     virtual ~PluginKateTextFilter();
 
     void addView (Kate::MainWindow *win);
