@@ -1,6 +1,5 @@
 /***************************************************************************
 	plugin_katexmltools.cpp
-	$Id: plugin_katexmltools.cpp,v 1.19 2002/10/13 22:20:01 dnaber Exp $
 
 	List elements, attributes, attribute values and entities allowed by DTD.
 	Needs a DTD in XML format (as produced by dtdparse) for most features.
@@ -33,14 +32,14 @@ spec is not followed, e.g. one can add the same attribute twice to an element.
 Also see the user documentation. If backspace is pressed after a completion popup
 was closed, the popup will re-open. This way typos can be corrected and the popup
 will reappear, which is quite comfortable.
-  
+
 FIXME for jowenn if he has time:
 -Ctrl-Z doesn't work if completion is visible
 -Typing with popup works, but right/left cursor keys and start/end don't, i.e.
  they should be ignored by the completion (?)
 -popup not completely visible if it's long and appears at the bottom of the screen
 
-FIXME: 
+FIXME:
 -(docbook) <author lang="">: insert space between the quotes, press "de" and return -> only "d" inserted
 -Correctly support more than one view:
  charactersInteractivelyInserted(..) is tied to kv->document()
@@ -90,6 +89,7 @@ TODO:
 
 #include <kaction.h>
 #include <kbuttonbox.h>
+#include <klineedit.h>
 #include <kcursor.h>
 #include <kdebug.h>
 #include <kfiledialog.h>
@@ -99,6 +99,9 @@ TODO:
 #include <klocale.h>
 #include <kmessagebox.h>
 #include <kstandarddirs.h>
+#include <kgenericfactory.h>
+       
+K_EXPORT_COMPONENT_FACTORY( katexmltoolsplugin, KGenericFactory<PluginKateXMLTools>( "katexmltools" ) )
 
 class PluginView : public KXMLGUIClient
 {
@@ -108,49 +111,22 @@ class PluginView : public KXMLGUIClient
 	Kate::MainWindow *win;
 };
 
-
-extern "C"
-{
-	void* init_katexmltoolsplugin()
-	{
-		KGlobal::locale()->insertCatalogue("katexmltools"); 
-		return new KatePluginFactory;
-	}
-}
-
-KatePluginFactory::KatePluginFactory()
-{
-	s_instance = new KInstance("kate");
-}
-
-KatePluginFactory::~KatePluginFactory()
-{
-	delete s_instance;
-}
-
-QObject* KatePluginFactory::createObject( QObject* parent, const char* name, const char*, const QStringList & )
-{
-	return new PluginKateXMLTools( parent, name );
-}
-
-KInstance* KatePluginFactory::s_instance = 0L;
-
-PluginKateXMLTools::PluginKateXMLTools(QObject* parent, const char* name)
+PluginKateXMLTools::PluginKateXMLTools(QObject* parent, const char* name, const QStringList&)
 	: Kate::Plugin ((Kate::Application*)parent, name)
 {
 	//kdDebug() << "PluginKateXMLTools constructor called" << endl;
-	
+
 	m_dtd_string = QString();
-	m_url_string = QString(); 
-	
+	m_url_string = QString();
+
 	m_mode = none;
 	m_correct_pos = 0;
-	
+
 	m_last_line = 0;
 	m_last_col = 0;
 	m_last_allowed = QStringList();
 	m_popup_open_col = -1;
-	
+
 	m_dtds.setAutoDelete(true);
 }
 
@@ -174,7 +150,7 @@ void PluginKateXMLTools::addView(Kate::MainWindow *win)
 	view->setXMLFile("plugins/katexmltools/ui.rc");
 	win->guiFactory()->addClient( view );
 	view->win = win;
-	m_views.append( view ); 
+	m_views.append( view );
 }
 
 void PluginKateXMLTools::removeView(Kate::MainWindow *win)
@@ -193,6 +169,10 @@ void PluginKateXMLTools::removeView(Kate::MainWindow *win)
 void PluginKateXMLTools::backspacePressed()
 {
 	kdDebug() << "xml tools backspacePressed" << endl;
+
+        if (!application()->activeMainWindow())
+          return;
+          
 	Kate::View *kv = application()->activeMainWindow()->viewManager()->activeView();
 	if( ! kv ) {
 		kdDebug() << "Warning: no Kate::View" << endl;
@@ -208,6 +188,7 @@ void PluginKateXMLTools::backspacePressed()
 			return;
 		}
 		//kdDebug() << "++ redisplay popup, " << m_last_allowed.count() << ", len:" << len <<endl;
+		connectSlots(kv);
 		kv->showCompletionBox(stringListToCompletionEntryList(m_last_allowed), len, false);
 	}
 	return;
@@ -222,6 +203,9 @@ void PluginKateXMLTools::keyEvent(int, int, const QString &/*s*/)
 {
 	//kdDebug() << "xml tools keyEvent: '" << s << endl;
 
+        if (!application()->activeMainWindow())
+          return;
+        
 	Kate::View *kv = application()->activeMainWindow()->viewManager()->activeView();
 	if( ! kv ) {
 		kdDebug() << "Warning: no Kate::View" << endl;
@@ -233,7 +217,7 @@ void PluginKateXMLTools::keyEvent(int, int, const QString &/*s*/)
 		//kdDebug() << "not ready, no meta DTD assigned yet for this view/document" << endl;
 		return;
 	}
-	
+
 	// debug to test speed:
 	//QTime t; t.start();
 
@@ -262,7 +246,7 @@ void PluginKateXMLTools::keyEvent(int, int, const QString &/*s*/)
 	//} else if( left_ch == ">" ) {
 	// TODO: optionally close parent tag if not left=="/>"
 	} else if( left_ch == " " || (isQuote(left_ch) && second_left_ch == "=") ) {
-	// TODO: check second_left_char, too?! then you don't need to trigger 
+	// TODO: check second_left_char, too?! then you don't need to trigger
 	// with space and we yet save CPU power
 		QString current_element = insideTag(*kv);
 		QString current_attribute;
@@ -274,7 +258,7 @@ void PluginKateXMLTools::keyEvent(int, int, const QString &/*s*/)
 		if( ! current_element.isEmpty() && ! current_attribute.isEmpty() ) {
 			kdDebug() << "*inside attribute -> get attribute values" << endl;
 			allowed = m_dtds[kv->document()]->getAllowedAttributeValuesFast(current_element, current_attribute);
-			if( allowed.count() == 1 && 
+			if( allowed.count() == 1 &&
 				(allowed[0] == "CDATA" || allowed[0] == "ID" || allowed[0] == "IDREF" ||
 				allowed[0] == "IDREFS" || allowed[0] == "ENTITY" || allowed[0] == "ENTITIES" ||
 				allowed[0] == "NMTOKEN" || allowed[0] == "NMTOKENS" || allowed[0] == "NAME") ) {
@@ -289,16 +273,17 @@ void PluginKateXMLTools::keyEvent(int, int, const QString &/*s*/)
 			m_mode = attributes;
 		}
 	}
-	
+
 	//kdDebug() << "time elapsed (ms): " << t.elapsed() << endl;
 	//kdDebug() << "Allowed strings: " << allowed.count() << endl;
-	
-	if( allowed.count() >= 1 ) {
+
+	if( allowed.count() >= 1 && allowed[0] != "__EMPTY" ) {
 		allowed = sortQStringList(allowed);
+		connectSlots(kv);
 		kv->showCompletionBox(stringListToCompletionEntryList(allowed), 0, false);
 		m_popup_open_col = col;
 		m_last_allowed = allowed;
-	} 
+	}
 	//else {
 	//	m_last_allowed.clear();
 	//}
@@ -316,11 +301,40 @@ PluginKateXMLTools::stringListToCompletionEntryList(QStringList list)
 	return comp_list;
 }
 
+
+/** disconnect all signals of a specified kateview from the local slots
+  *
+  */
+void  PluginKateXMLTools::disconnectSlots(Kate::View *kv)
+{
+	disconnect(kv, SIGNAL(filterInsertString(KTextEditor::CompletionEntry*,QString*)), 0, 0);
+	disconnect(kv, SIGNAL(completionDone(KTextEditor::CompletionEntry)), 0, 0);
+	disconnect(kv, SIGNAL(completionAborted()), 0, 0);
+}
+
+/** connect all signals of a specified kateview to the local slots
+  *
+  */
+void PluginKateXMLTools::connectSlots(Kate::View *kv)
+{
+	// disconnect everything so signals don't arrive twice if the user selects a new meta dtd:
+
+	connect(kv, SIGNAL(filterInsertString(KTextEditor::CompletionEntry*,QString*)),
+		this, SLOT(filterInsertString(KTextEditor::CompletionEntry*,QString*)));
+
+	connect(kv, SIGNAL(completionDone(KTextEditor::CompletionEntry)),
+		this, SLOT(completionDone(KTextEditor::CompletionEntry)));
+
+	connect(kv, SIGNAL(completionAborted()), this, SLOT(completionAborted()));
+}
+
 /** Load the meta DTD. In case of success set the 'ready'
   * flag to true, to show that we're is ready to give hints about the DTD.
   */
 void PluginKateXMLTools::getDTD()
 {
+        if (!application()->activeMainWindow())
+          return;
 
 	Kate::View *kv = application()->activeMainWindow()->viewManager()->activeView();
 	if( ! kv ) {
@@ -328,26 +342,17 @@ void PluginKateXMLTools::getDTD()
 		return;
 	}
 
-	// disconnect everything so signals don't arrive twice if the user selects a new meta dtd:
+	disconnect(kv->document(), SIGNAL(charactersInteractivelyInserted(int,int,const QString&)), 0, 0);
+	connect(kv->document(), SIGNAL(charactersInteractivelyInserted(int,int,const QString&)),
+				this, SLOT(keyEvent(int,int,const QString&)));
 
 	disconnect(kv->document(), SIGNAL(backspacePressed()), 0, 0);
 	connect(kv->document(), SIGNAL(backspacePressed()),
 				this, SLOT(backspacePressed()));
 
-	disconnect(kv->document(), SIGNAL(charactersInteractivelyInserted(int,int,const QString&)), 0, 0);
-	connect(kv->document(), SIGNAL(charactersInteractivelyInserted(int,int,const QString&)),
-				this, SLOT(keyEvent(int,int,const QString&)));
+//	disconnectSlots(kv);
+//	connectSlots(kv);
 
-	disconnect(kv, SIGNAL(filterInsertString(KTextEditor::CompletionEntry*,QString*)), 0, 0);
-	connect(kv, SIGNAL(filterInsertString(KTextEditor::CompletionEntry*,QString*)),
-		this, SLOT(filterInsertString(KTextEditor::CompletionEntry*,QString*)));
-
-	disconnect(kv, SIGNAL(completionDone(KTextEditor::CompletionEntry)), 0, 0);
-	connect(kv, SIGNAL(completionDone(KTextEditor::CompletionEntry)),
-		this, SLOT(completionDone(KTextEditor::CompletionEntry)));
-
-	disconnect(kv, SIGNAL(completionAborted()), 0, 0);
-	connect(kv, SIGNAL(completionAborted()), this, SLOT(completionAborted()));
 
 	/* Start where the supplied XML-DTDs are installed by default unless
 	   user changed directory last time:
@@ -393,10 +398,10 @@ void PluginKateXMLTools::getDTD()
 		} else if ( doctype == "-//KDE//DTD DocBook XML V4.1.2-Based Variant V1.1//EN" ) {
 			filename = "kde-docbook.dtd.xml";
 		}
-	} else if( document_start.find("<xsl:stylesheet") != -1 && 
+	} else if( document_start.find("<xsl:stylesheet") != -1 &&
 				document_start.find("xmlns:xsl=\"http://www.w3.org/1999/XSL/Transform\"") != -1 ) {
 		/* XSLT doesn't have a doctype/DTD. We look for an xsl:stylesheet tag instead.
-		   Example: 
+		   Example:
 			<xsl:stylesheet version="1.0"
 				xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
 				xmlns="http://www.w3.org/TR/xhtml1/strict">
@@ -444,6 +449,10 @@ void PluginKateXMLTools::slotFinished(KIO::Job *job)
 	} else {
 		PseudoDTD *dtd = new PseudoDTD();
 		dtd->analyzeDTD(m_url_string, m_dtd_string);
+                
+                if (!application()->activeMainWindow())
+                  return;
+                
 		Kate::View *kv = application()->activeMainWindow()->viewManager()->activeView();
 		if( ! kv ) {
 			kdDebug() << "Warning: no Kate::View" << endl;
@@ -459,12 +468,15 @@ void PluginKateXMLTools::slotData(KIO::Job *, const QByteArray &data)
 	m_dtd_string += QString(data);
 }
 
-/** Offer a line edit with completion for possible elements at cursor position and insert the 
+/** Offer a line edit with completion for possible elements at cursor position and insert the
   * tag one chosen/entered by the user, plus its closing tag. If there's a text selection,
-  * add the markup around it. 
+  * add the markup around it.
   */
 void PluginKateXMLTools::slotInsertElement()
 {
+        if (!application()->activeMainWindow())
+          return;
+
 	Kate::View *kv = application()->activeMainWindow()->viewManager()->activeView();
 	if( ! kv ) {
 		kdDebug() << "Warning: no Kate::View" << endl;
@@ -513,10 +525,6 @@ void PluginKateXMLTools::slotInsertElement()
 			kv->getDoc()->removeSelectedText();
 		}
 		kv->insertText(pre + marked + post);
-		// place cursor after tag name:
-		for( uint i = pre.length()-adjust; i > 0; i-- ) {
-			kv->cursorRight();
-		}
 
 	}
 }
@@ -525,6 +533,9 @@ void PluginKateXMLTools::slotInsertElement()
   */
 void PluginKateXMLTools::slotCloseElement()
 {
+        if (!application()->activeMainWindow())
+          return;
+
 	Kate::View *kv = application()->activeMainWindow()->viewManager()->activeView();
 	if( ! kv ) {
 		kdDebug() << "Warning: no Kate::View" << endl;
@@ -535,9 +546,6 @@ void PluginKateXMLTools::slotCloseElement()
 	QString close_tag = "</" + parent_element + ">";
 	if( ! parent_element.isEmpty() ) {
 		kv->insertText(close_tag);
-		for( uint i = 0; i < close_tag.length(); i++ ) {
-			kv->cursorRight();
-		}
 	}
 }
 
@@ -547,6 +555,9 @@ void PluginKateXMLTools::filterInsertString(KTextEditor::CompletionEntry *ce, QS
 	kdDebug() << "filterInsertString str: " << *text << endl;
 	kdDebug() << "filterInsertString text: " << ce->text << endl;
 
+        if (!application()->activeMainWindow())
+          return;
+        
 	Kate::View *kv = application()->activeMainWindow()->viewManager()->activeView();
 	if( ! kv ) {
 		kdDebug() << "Warning (filterInsertString()): no Kate::View" << endl;
@@ -617,11 +628,15 @@ void PluginKateXMLTools::filterInsertString(KTextEditor::CompletionEntry *ce, QS
 
 void PluginKateXMLTools::completionAborted()
 {
+        if (!application()->activeMainWindow())
+          return;
+
 	Kate::View *kv = application()->activeMainWindow()->viewManager()->activeView();
 	if( ! kv ) {
 		kdDebug() << "Warning (completionAborted()): no Kate::View" << endl;
 		return;
 	}
+	disconnectSlots(kv);
 	kv->cursorPositionReal(&m_last_line, &m_last_col);
 	m_last_col--;
 	kdDebug() << "completionAborted() at line:" << m_last_line << ", col:" << m_last_col << endl;
@@ -630,12 +645,16 @@ void PluginKateXMLTools::completionAborted()
 void PluginKateXMLTools::completionDone(KTextEditor::CompletionEntry)
 {
 	kdDebug() << "completionDone()" << endl;
-	
+        
+        if (!application()->activeMainWindow())
+          return;
+
 	Kate::View *kv = application()->activeMainWindow()->viewManager()->activeView();
 	if( ! kv ) {
 		kdDebug() << "Warning (completionDone()): no Kate::View" << endl;
 		return;
 	}
+	disconnectSlots(kv);	
 
 	if( m_correct_pos > 0 ) {
 		for( int i = 0; i < m_correct_pos; i++ ) {
@@ -651,6 +670,7 @@ void PluginKateXMLTools::completionDone(KTextEditor::CompletionEntry)
 		// immediately show attribute values:
 		QTimer::singleShot(10, this, SLOT(emptyKeyEvent()));
 	}
+	
 }
 
 // ========================================================================
@@ -696,7 +716,7 @@ QString PluginKateXMLTools::insideTag(Kate::View &kv)
 
 /** Check if cursor is inside an attribute value, that is
   * if '="' is on the left, and if it's nearer than "<" or ">".
-  * Return the attribute name or "" if we're outside an attribute 
+  * Return the attribute name or "" if we're outside an attribute
   * value.
   * Note: only call when insideTag() == true.
   * TODO: allow whitespace around "="
@@ -778,7 +798,9 @@ QString PluginKateXMLTools::getParentElement(Kate::View &kv, bool ignore_single_
 				tag = "";
 			} else if( ch == "<" ) {
 				in_tag = false;
-				if( isOpeningTag("<"+tag+">") ) {
+				if( isEmptyTag("<"+tag+">") ) {
+					// do nothing
+				} else if( isOpeningTag("<"+tag+">") ) {
 					nesting_level--;
 				} else if( isClosingTag("<"+tag+">") ) {
 					nesting_level++;
@@ -794,7 +816,7 @@ QString PluginKateXMLTools::getParentElement(Kate::View &kv, bool ignore_single_
 				}
 				// "else": empty tags can be ignored
 			} else if( in_tag == true && y != y_prev ) {
-				tag = ch + "\n" + tag;		// we're moving left and changing rows
+				tag = ch + tag;		// we're moving left and changing rows
 				y_prev = y;
 			} else if( in_tag == true ) {
 				tag = ch + tag;		// we're moving left!
@@ -813,7 +835,7 @@ QString PluginKateXMLTools::getParentElement(Kate::View &kv, bool ignore_single_
   */
 bool PluginKateXMLTools::isOpeningTag(QString tag)
 {
-	if( !isClosingTag(tag) && !isEmptyTag(tag) && 
+	if( !isClosingTag(tag) && !isEmptyTag(tag) &&
 		!tag.startsWith("<?") && !tag.startsWith("<!") ) {
 		return true;
 	} else {
@@ -900,6 +922,11 @@ InsertElement::~InsertElement()
 {
 }
 
+void InsertElement::slotHistoryTextChanged(const QString& text)
+{
+	enableButtonOK(!text.isEmpty());
+}
+
 QString InsertElement::showDialog(QStringList &completions)
 {
 	QWidget *page = new QWidget(this);
@@ -908,7 +935,7 @@ QString InsertElement::showDialog(QStringList &completions)
 
 	KHistoryCombo *combo = new KHistoryCombo(page, "value");
 	combo->setHistoryItems(completions, true);
-
+		connect(combo->lineEdit(), SIGNAL(textChanged ( const QString & )),this,SLOT( slotHistoryTextChanged(const QString &)));
 	QString text = i18n("Enter XML tag name and attributes. The \"<\", \">\" and closing tag will be supplied.");
 	QLabel *label = new QLabel(text, page, "insert");
 
@@ -916,7 +943,7 @@ QString InsertElement::showDialog(QStringList &completions)
 	topLayout->addWidget(combo);
 
 	combo->setFocus();
-
+	slotHistoryTextChanged(combo->lineEdit()->text());
 	if( exec() ) {
 		return combo->currentText();
 	}
