@@ -1,10 +1,9 @@
  /***************************************************************************
     plugin_katexmltools.cpp
-    $Id: plugin_katexmltools.h,v 1.7 2002/07/20 14:06:20 dnaber Exp $
     copyright            : (C) 2001-2002 by Daniel Naber
     email                : daniel.naber@t-online.de
  ***************************************************************************/
- 
+
 /***************************************************************************
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
@@ -44,23 +43,6 @@
 #include <kcombobox.h>
 #include <kdialog.h>
 #include <kdialogbase.h>
-#include <klibloader.h>
-
-class KatePluginFactory : public KLibFactory
-{
-
-Q_OBJECT
-
-public:
-	KatePluginFactory();
-	virtual ~KatePluginFactory();
-
-	virtual QObject* createObject( QObject* parent = 0, const char* pname = 0, const char* name = "QObject", const QStringList &args = QStringList() );
-
-private:
-	static KInstance* s_instance;
-
-};
 
 class PluginKateXMLTools : public Kate::Plugin, Kate::PluginViewInterface
 {
@@ -69,12 +51,12 @@ Q_OBJECT
 
 public:
 
-	PluginKateXMLTools( QObject* parent = 0, const char* name = 0 );
+	PluginKateXMLTools(QObject* parent = 0, const char* name = 0, const QStringList& = QStringList());
 	virtual ~PluginKateXMLTools();
 	void addView (Kate::MainWindow *win);
         void removeView(Kate::MainWindow *win);
-    
-        
+
+
 public slots:
 
 	void getDTD();
@@ -84,7 +66,7 @@ public slots:
 	void filterInsertString(KTextEditor::CompletionEntry *ce, QString *str);
 	void completionDone(KTextEditor::CompletionEntry completion_entry);
 	void completionAborted();
-	
+
 	void slotFinished(KIO::Job *job);
 	void slotData(KIO::Job *, const QByteArray &data);
 
@@ -104,7 +86,7 @@ protected:
 	bool isClosingTag(QString tag);
 	bool isEmptyTag(QString tag);
 	bool isQuote(QString ch);
-	
+
 	QString getParentElement(Kate::View &view, bool ignore_single_bracket);
 
 	enum Mode {none, entities, attributevalues, attributes, elements};
@@ -114,7 +96,7 @@ protected:
 
 	QString m_dtd_string;
 	QString m_url_string;
-	
+
 	uint m_last_line, m_last_col;
 	QStringList m_last_allowed;
 	int m_popup_open_col;
@@ -127,7 +109,11 @@ protected:
 
 	QPtrDict<PseudoDTD> m_dtds;
 
-	QPtrList<class PluginView> m_views;      
+	QPtrList<class PluginView> m_views;
+
+
+	void connectSlots(Kate::View *kv);
+	void disconnectSlots(Kate::View *kv);
 };
 
 class InsertElement : public KDialogBase
@@ -139,6 +125,8 @@ public:
 	InsertElement(QWidget *parent, const char *name);
 	~InsertElement();
 	QString showDialog(QStringList &completions);
+private slots:
+    void slotHistoryTextChanged(const QString& );
 
 };
 
