@@ -115,7 +115,7 @@ bool KDotDesktopPlugin::readInfo( KFileMetaInfo& info, uint )
     }
     else if (type == "Link")
     {
-        QString url = file.readEntry("URL");
+        QString url = file.readPathEntry("URL");
         appendItem(group, "Link To", url);
     }
 
