@@ -50,7 +50,7 @@ void KTxtPlugin::makeMimeTypeInfo(const QString& mimeType)
     setAttributes(item, KFileMimeTypeInfo::Averaged);
     item = addItemInfo(group, "Words", i18n("Words"), QVariant::Int);
     setAttributes(item, KFileMimeTypeInfo::Averaged);
-    item = addItemInfo(group, "Characters", i18n("Characters"), QVariant::Int);
+    item = addItemInfo(group, "Characters", i18n("Characters"), QVariant::ULongLong);
     setAttributes(item, KFileMimeTypeInfo::Averaged);
     item = addItemInfo(group, "Format", i18n("Format"), QVariant::String);
 }
@@ -64,12 +64,12 @@ bool KTxtPlugin::readInfo(KFileMetaInfo& info, uint)
     bool firstline = true;
     int totLines = 0;
     int totWords = 0;
-    int totChars = f.size();
+    unsigned long long totChars = f.size();
     QString fileFormat;
     QString line;
     bool skipTotals = (totChars > 100*1024); // 100K is the max we read
  
-    int bytesRead = 0;
+    unsigned int bytesRead = 0;
     while (!f.atEnd())
     {
         f.readLine(line, 4096);
@@ -109,7 +109,7 @@ bool KTxtPlugin::readInfo(KFileMetaInfo& info, uint)
 
     kdDebug(7034) << "Lines: " << totLines << endl;
     kdDebug(7034) << "Words: " << totWords << endl;
-    kdDebug(7034) << "Characters: " << totChars << endl;
+    //kdDebug(7034) << "Characters: " << totChars << endl;
     kdDebug(7034) << "fileFormat: " << fileFormat << endl;
 
     KFileMetaInfoGroup group = appendGroup(info, "General");
