@@ -21,12 +21,13 @@
 #include <qcolor.h>
 #include <qcheckbox.h>
 #include <qtabdialog.h>
-#include <qcombobox.h>
 
 #include <kcolorbutton.h>
+#include <kcombobox.h>
 #include <klineedit.h>
 #include <knuminput.h>
 #include <kdialogbase.h>
+#include <kurlrequester.h>
 
 #include "timemon.h"
 
@@ -43,7 +44,7 @@ class KColorButton;
  * KConfDialog
  */
 
-class KConfDialog : public KDialogBase 
+class KConfDialog : public KDialogBase
 {
 
     Q_OBJECT
@@ -65,13 +66,12 @@ public:
   QColor getBgColour() const { return bgCB->color(); }
 
   bool getAutoScale() const { return autoScaleBox->isChecked(); }
-  bool getToolTip() const { return toolTipBox->isChecked(); }
   unsigned getPageScale() const { return pageScaleEdit->value(); }
   unsigned getSwapScale() const { return swapScaleEdit->value(); }
   unsigned getCtxScale() const { return ctxScaleEdit->value(); }
 
-  unsigned getMouseAction(int i) const { return mouseC[i]->currentItem(); }
-  QString getMouseActionCommand(int i) const { return mouseLE[i]->text(); }
+  unsigned getMouseAction(int i) const;
+  QString getMouseActionCommand(int i) const { return mouseLE[i]->lineEdit()->text(); }
 
 private slots:
   void updateSampleWidget(const QColor &); // update colours in configuration
@@ -83,12 +83,12 @@ private:
   KTimeMon *timemon;
   KIntNumInput *intervalEdit, *swapScaleEdit, *pageScaleEdit, *ctxScaleEdit;
   QLineEdit *procFileEdit;
-  QCheckBox *autoScaleBox, *toolTipBox;
+  QCheckBox *autoScaleBox;
   KColorButton *kernelCB, *userCB, *niceCB;
   KColorButton *buffersCB, *usedCB, *cachedCB;
   KColorButton *swapCB, *bgCB;
-  KLineEdit *mouseLE[MAX_MOUSE_ACTIONS];
-  QComboBox *mouseC[MAX_MOUSE_ACTIONS];
+  KURLRequester *mouseLE[MAX_MOUSE_ACTIONS];
+  KComboBox *mouseC[MAX_MOUSE_ACTIONS];
   bool haveWarned;
 
   friend class KTimeMon;
