@@ -26,12 +26,14 @@
 #include "configfrontend.h"
 #include "xmmsInterface.h"
 #include "noatunInterface.h"
+#include "jukInterface.h"
 
 #include <qfile.h>
 #include <qdragobject.h>
 #include <qtooltip.h>
 #include <qstyle.h>
 #include <qpainter.h>
+#include <qpopupmenu.h>
 
 #include <kapplication.h>
 #include <kipc.h>
@@ -105,6 +107,10 @@ MediaControl::MediaControl(const QString &configFile, Type t, int actions, QWidg
 	connect(kapp, SIGNAL(iconChanged(int)), this, SLOT(slotIconChanged()));
 
 	reparseConfig();
+
+	rmbMenu = new QPopupMenu(this, "RMB Menu");
+	rmbMenu->insertItem(SmallIcon("configure"), i18n("Configure MediaControl..."), this, SLOT(preferences()));
+	rmbMenu->insertItem(i18n("About MediaControl"), this, SLOT(about()));
 }
 
 MediaControl::~MediaControl()
@@ -112,6 +118,7 @@ MediaControl::~MediaControl()
 	delete _player;
 	delete _configFrontend;
 	delete _dcopClient;
+        KGlobal::locale()->removeCatalogue("mediacontrol");
 }
 
 // Drag-n-Drop stuff ==================================================================
@@ -171,7 +178,7 @@ void MediaControl::slotIconChanged()
 	if(!_configFrontend->useCustomTheme())
 	{
 		prev_button->setPixmap ( SmallIcon("player_start.png") );
-		play_button->setPixmap ( SmallIcon("1rightarrow.png") );
+		play_button->setPixmap ( SmallIcon("player_play.png") );
 		pause_button->setPixmap ( SmallIcon("player_pause.png") );
 		stop_button->setPixmap ( SmallIcon("player_stop.png") );
 		next_button->setPixmap ( SmallIcon("player_end.png") );
@@ -283,14 +290,22 @@ void MediaControl::reparseConfig()
 		time_slider->setSteps((_configFrontend->mouseWheelSpeed()*1000),
 			(_configFrontend->mouseWheelSpeed()*1000));
 	}
-	else // player is noatun or something wrong was written to the config
+	// player is noatun or something wrong was written to the config
 #endif
-	{
+	if ( playerString == "Noatun")
+        {
 //		kdDebug() << "player = Noatun" << endl;
 		_player = new NoatunInterface();
 		time_slider->setSteps((_configFrontend->mouseWheelSpeed()),
 			(_configFrontend->mouseWheelSpeed()));
 	}
+        if ( playerString == "JuK")
+        {
+                kdDebug() << "player = JuK" << endl;
+                _player = new JuKInterface();
+		time_slider->setSteps((_configFrontend->mouseWheelSpeed()),
+			(_configFrontend->mouseWheelSpeed()));
+        }
 
 	//  this signal gets emitted by a playerInterface when the player's playtime changed
 	connect(_player, SIGNAL(newSliderPosition(int,int)), SLOT(setSliderPosition(int,int)));
@@ -387,6 +402,11 @@ int MediaControl::heightForWidth(int width) const
 	}
 }
 
+void MediaControl::mousePressEvent(QMouseEvent* e)
+{
+	rmbMenu->popup(e->globalPos());
+}
+
 // Danger: Weird Code ahead! ;))
 void MediaControl::resizeEvent( QResizeEvent* )
 {
