@@ -46,6 +46,7 @@
 
 #define MEDIACONTROL_VERSION "0.3"
 
+class QPopupMenu;
 class KInstance;
 class MediaControlConfig;
 // ===============================================================
@@ -74,14 +75,16 @@ class MediaControl : public KPanelApplet, virtual public MediaControlIface
 		MediaControl(const QString&, Type, int ,QWidget * = 0, const char * = 0);
 		virtual ~MediaControl();
 
-		void about();
-		void preferences();
 		int widthForHeight(int height) const;
 		int heightForWidth(int width) const;
 		void dragEnterEvent(QDragEnterEvent* event);
 		void dropEvent(QDropEvent* event);
 		virtual void reparseConfig();
 
+	public slots:
+		void about();
+		void preferences();
+
 	private:
 		KInstance *_instance;
 		DCOPClient *_dcopClient;
@@ -95,6 +98,9 @@ class MediaControl : public KPanelApplet, virtual public MediaControlIface
 		TrayButton *next_button;  // GoTo Next Playlist-Item
 		QSlider *time_slider;
 		int lastLen, lastTime;
+		QPopupMenu *rmbMenu;
+
+		virtual void mousePressEvent(QMouseEvent* e);
 		void resizeEvent(QResizeEvent*);
 
 		friend class MediaControlToolTip;
