@@ -21,6 +21,7 @@
 #include <kdebug.h>
 #include <qstringlist.h>
 #include <qstrlist.h>
+#include <kurldrag.h>
 
 #define TIMER_FAST  250
 
@@ -153,20 +154,18 @@ void NoatunInterface::updateSlider ( void )
 void NoatunInterface::dragEnterEvent(QDragEnterEvent* event)
 {
 //	kdDebug() << "NoatunInterface::dragEnterEvent()" << endl;
-	event->accept( QUriDrag::canDecode(event) );
+	event->accept( KURLDrag::canDecode(event) );
 }
 
 void NoatunInterface::dropEvent(QDropEvent* event)
 {
 //	kdDebug() << "NoatunInterface::dropEvent()" << endl;
-	QStrList uri;
-	if (QUriDrag::decode(event, uri))
+	KURL::List list;
+	if (KURLDrag::decode(event, list))
 	{
-//		for (char *file=uri.first(); file != 0; file=uri.next() )
-//			kdDebug() << "uri: " << file << endl;
 		QByteArray data;
 		QDataStream arg(data, IO_WriteOnly);
-		arg << QStringList::fromStrList(uri) << false;
+		arg << list.toStringList() << false;
 		if (!kapp->dcopClient()->send(mAppId, "Noatun", "addFile(QStringList,bool)",data))
 			kdDebug() << "Couldn't send drop to noatun" << endl;
 	}
