@@ -32,7 +32,7 @@ PluginBabelFish::PluginBabelFish( QObject* parent, const char* name,
 	                          const QStringList & )
   : Plugin( parent, name )
 {
-  m_menu = new KActionMenu( i18n("Tr&anslate Web Page"), "babelfish",
+  m_menu = new KActionMenu( i18n("Translate Web &Page"), "babelfish",
                           actionCollection(), "translatewebpage" );
   m_menu->setDelayed( false );
 
@@ -132,7 +132,7 @@ void PluginBabelFish::translateURL()
   // The parent is assumed to be a KHTMLPart
   if ( !parent()->inherits("KHTMLPart") )
   {
-    QString title = i18n( "Cannot translate source" );
+    QString title = i18n( "Cannot Translate Source" );
     QString text = i18n( "Only web pages can be translated using "
                          "this plugin." );
 
@@ -156,7 +156,7 @@ void PluginBabelFish::translateURL()
     query = "url=" + KURL::encode_string( url.url() );
 
     // Check syntax
-    if ( url.isMalformed() )
+    if ( !url.isValid() )
     {
       QString title = i18n( "Malformed URL" );
       QString text = i18n( "The URL you entered is not valid, please "
