@@ -87,12 +87,10 @@ protected:
     MimeInfo()
     {
       id = 0;
-      count = 0;
       useAsFilter = false;
     };
 
     int id;
-    int count;
     bool useAsFilter;
 
     QString mimeType;
