@@ -16,7 +16,7 @@
  *                                                                         *
  ***************************************************************************/
 
-/* $Id: domtreeview.cpp,v 1.27 2002/08/25 09:51:01 mlaurent Exp $ */
+/* $Id: domtreeview.cpp,v 1.31 2003/11/03 17:18:00 nhasan Exp $ */
 
 #include <assert.h>
 
@@ -25,6 +25,7 @@
 #include <qlayout.h>
 #include <qfont.h>
 #include <qfile.h>
+#include <qtextstream.h>
 
 #include <dom/dom_element.h>
 #include <dom/dom_node.h>
@@ -36,6 +37,9 @@
 #include <klocale.h>
 #include <kglobalsettings.h>
 #include <kdebug.h>
+#include <klistview.h>
+#include <kstdguiitem.h>
+#include <kpushbutton.h>
 
 #include "domtreeview.h"
 #include <qpushbutton.h>
@@ -47,7 +51,7 @@ DOMTreeView::DOMTreeView(QWidget *parent, KHTMLPart *_part, const char* name, bo
 {
   part = _part;
 
-  setCaption( i18n( "DOM Tree for %1" ).arg(part->url().url()) );
+  setCaption( i18n( "DOM Tree for %1" ).arg(part->url().prettyURL()) );
   setMinimumHeight(600);
   setMinimumWidth(400);
 
@@ -88,12 +92,12 @@ DOMTreeView::DOMTreeView(QWidget *parent, KHTMLPart *_part, const char* name, bo
   QSpacerItem* spacer1 = new QSpacerItem( 20, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
   m_hLayout1->addItem( spacer1 );
 
-  m_decreaseButton = new QPushButton( this );
+  m_decreaseButton = new KPushButton( this );
   m_decreaseButton->setText( "&<" );
   connect(m_decreaseButton, SIGNAL(clicked()), this, SLOT(slotDecrExpansionDepth()));
   m_hLayout1->addWidget( m_decreaseButton );
 
-  m_increaseButton = new QPushButton( this );
+  m_increaseButton = new KPushButton( this );
   m_increaseButton->setText( "&>" );
   connect(m_increaseButton, SIGNAL(clicked()), this, SLOT(slotIncrExpansionDepth()));
 
@@ -105,8 +109,8 @@ DOMTreeView::DOMTreeView(QWidget *parent, KHTMLPart *_part, const char* name, bo
   m_hLayout2->setSpacing( 2 );
   m_hLayout2->setMargin( 2 );
 
-  m_findButton = new QPushButton( this );
-  m_findButton->setText( i18n( "&Find..." ) );
+  m_findButton = new KPushButton( this );
+  m_findButton->setGuiItem( KGuiItem( i18n( "&Find..." ), "find" ) );
   connect(m_findButton, SIGNAL(clicked()), this, SLOT(slotFindClicked()));
   m_hLayout2->addWidget( m_findButton );
 
@@ -114,19 +118,18 @@ DOMTreeView::DOMTreeView(QWidget *parent, KHTMLPart *_part, const char* name, bo
   m_hLayout2->addItem( spacer2 );
 
   if (allowSaving) {
-    m_saveButton = new QPushButton( this );
+    m_saveButton = new KPushButton( this );
     m_saveButton->setText( i18n( "&Save as HTML..." ) );
     connect(m_saveButton, SIGNAL(clicked()), this, SLOT(slotSaveClicked()));
     m_hLayout2->addWidget( m_saveButton );
   }
 
-  m_refreshButton = new QPushButton( this );
-  m_refreshButton->setText( i18n( "&Refresh" ) );
+  m_refreshButton = new KPushButton( this );
+  m_refreshButton->setGuiItem( KGuiItem( i18n( "&Refresh" ), "reload" ) );
   connect(m_refreshButton, SIGNAL(clicked()), this, SLOT(slotRefreshClicked()));
   m_hLayout2->addWidget( m_refreshButton );
 
-  m_closeButton = new QPushButton( this );
-  m_closeButton->setText( i18n( "&Close" ) );
+  m_closeButton = new KPushButton( KStdGuiItem::close(), this );
   connect(m_closeButton, SIGNAL(clicked()), this, SLOT(close()));
 
   m_hLayout2->addWidget( m_closeButton );
@@ -454,7 +457,7 @@ void DOMTreeView::slotSaveClicked()
     QFile file(url.path());
 
     if (file.exists()) {
-      const QString title = i18n( "File exists" );
+      const QString title = i18n( "File Exists" );
       const QString text = i18n( "Do you really want to overwrite: \n%1?" ).arg(url.url());
       if (KMessageBox::Yes != KMessageBox::warningYesNoCancel(this, text, title ) ) {
 	return;
@@ -469,7 +472,7 @@ void DOMTreeView::slotSaveClicked()
       kdDebug() << "File closed " << endl;
       delete m_textStream;
     } else {
-      const QString title = i18n( "Unable to open file" );
+      const QString title = i18n( "Unable to Open File" );
       const QString text = i18n( "Unable to open \n %1 \n for writing" ).arg(url.path());
       KMessageBox::sorry( this, text, title );
     }
