@@ -1,6 +1,6 @@
 /* This file is part of the KDE project
 
-   Copyright (C) 2001 Lukas Tinkl <lukas@kde.org>
+   Copyright (C) 2001, 2003 Lukas Tinkl <lukas@kde.org>
                       Andreas Schlapbach <schlpbch@iam.unibe.ch>
 
    This library is free software; you can redistribute it and/or
@@ -21,17 +21,17 @@
 #ifndef kimdialogplugin_h
 #define kimdialogplugin_h
 
-#include <qcheckbox.h>
-#include <qlineedit.h>
-#include <qspinbox.h>
 
-#include <kcolorbutton.h>
-#include <kurlrequester.h>
 #include <kdialogbase.h>
 
 class QProgressDialog;
 class KURL;
 class KIntNumInput;
+class QCheckBox;
+class QLineEdit;
+class KURLRequester;
+class QSpinBox;
+class KColorButton;
 
 typedef QMap<QString,QString> CommentMap;
 
@@ -51,9 +51,11 @@ class KIGPDialog : public KDialogBase
   bool useCommentFile() const;
   bool recurseSubDirectories() const;
   int recursionLevel() const;
-  bool generateXHTML() const;
+  bool colorDepthSet() const;
 
   int getImagesPerRow() const;
+  int getThumbnailSize() const;
+  int getColorDepth() const;
 
   const QString getTitle() const;
   const QString getImageName() const;
@@ -64,6 +66,8 @@ class KIGPDialog : public KDialogBase
   const QColor getBackgroundColor() const;
   const QColor getForegroundColor() const;
 
+  const QString getImageFormat() const;
+
  protected slots:
   void imageUrlChanged(const QString & );
 
@@ -74,6 +78,7 @@ class KIGPDialog : public KDialogBase
   QLineEdit *m_title;
 
   KIntNumInput *m_imagesPerRow;
+  KIntNumInput *m_thumbnailSize;
   KIntNumInput *m_recursionLevel;
   QSpinBox *m_fontSize;
 
@@ -83,9 +88,11 @@ class KIGPDialog : public KDialogBase
   QCheckBox *m_imageProperty;
   QCheckBox *m_useCommentFile;
   QCheckBox *m_recurseSubDir;
-  QCheckBox *m_generateXHTML;
+  QCheckBox *m_colorDepthSet;
 
   QComboBox* m_fontName;
+  QComboBox* m_imageFormat;
+  QComboBox* m_colorDepth;
 
   KURLRequester *m_imageNameReq;
   KURLRequester *m_commentFileReq;
@@ -94,6 +101,7 @@ class KIGPDialog : public KDialogBase
  private:
   void setupLookPage(const QString& path);
   void setupDirectoryPage(const QString& path);
+  void setupThumbnailPage(const QString& path);
 };
 
 #endif
