@@ -26,7 +26,7 @@ class KCMKuick
 	Q_OBJECT
 
 public:
-	KCMKuick (QWidget *parent = 0, const char *name = 0);
+	KCMKuick (QWidget *parent, const char *name, const QStringList &);
         ~KCMKuick();	
 	void load();
 	void load(const QString &);
