@@ -24,6 +24,7 @@
 #include <kaction.h>
 #include <kiconloader.h>
 #include <klocale.h>
+#include <kurl.h>
 
 #include "kdirmenu.h"
 
@@ -31,7 +32,7 @@
 
 QMap<QString, QPixmap> *KDirMenu::_icons = 0;
 
-KDirMenu::KDirMenu ( QWidget *parent, const QString &_src, 
+KDirMenu::KDirMenu ( QWidget *parent, const KURL &_src,
             const QString &_path, const QString &_name, bool /*showfile*/ )
     : QPopupMenu(parent),
       path(_path),
@@ -45,9 +46,9 @@ KDirMenu::KDirMenu ( QWidget *parent, const QString &_src,
     connect( this, SIGNAL( aboutToHide( ) ), this, SLOT( slotAboutToHide( ) ) );
     children.clear(); // just in case
 
-    if ( src != path )
-        action = new KAction(i18n(name.utf8()), 0, this,
-                         SLOT(new_slot( ) ), this);
+    QFileInfo fileInfo(path);
+    if (( src.path() != path || !src.isLocalFile()) && fileInfo.isWritable())
+        action = new KAction(name, 0, this, SLOT(new_slot( ) ), this);
 }
 KDirMenu::~KDirMenu( ) {
     delete action;
@@ -66,34 +67,39 @@ void KDirMenu::slotAboutToShow( ) {
 
     // ok, prepare the dir: list all dirs and insert the new menus
     if (count() >= 1) return;
+    
+    //Precaution: if not a directory, exit, in case some path in KMetaMenu
+    //isn't checked right
+    if ( !QFileInfo(path).isDir() )
+        return;
 
     if ( action )
-    {
         action->plug( this );
-        insertSeparator( );
-    }
+    else
+	setItemEnabled( insertItem( name ), false );
+    insertSeparator( );
 
     // all dirs writeable and readable
     QDir dir(path, QString::null,
              QDir::Name | QDir::DirsFirst | QDir::IgnoreCase,
-             QDir::Dirs | QDir::Readable ); 
+             QDir::Dirs | QDir::Readable | QDir::Executable);
 
     QFileInfoList dirList = QFileInfoList(*(dir.entryInfoList()));
-    // remove . and ..
-    dirList.removeFirst();
-    dirList.removeFirst();
 
-    if (dirList.isEmpty()) {
-        insertItem(i18n("No Sub-directories"), 0);
+    if (dirList.count() == 2) {
+        insertItem(i18n("No Sub-Folders"), 0);
         setItemEnabled(0, false);
         return;
     }
 
     QFileInfo* fi;
     QString fileName;
+    static const QString& dot = KGlobal::staticQString( "." );
+    static const QString& dotdot = KGlobal::staticQString( ".." );
     for (fi = dirList.first(); fi; fi = dirList.next()) {
         fileName = fi->fileName();
-
+        if ( fileName == dot || fileName == dotdot )
+            continue;
         insert(new KDirMenu(this, src, fi->absFilePath(), name),
                fileName);
     }
