@@ -22,6 +22,7 @@
 #include <klocale.h>
 #include <kconfig.h>
 #include <kfiledialog.h>
+#include <kurl.h>
 #include <konq_popupmenu.h>
 
 #include <qpixmap.h>
@@ -43,18 +44,18 @@ KMetaMenu::KMetaMenu( QWidget *parent, const KURL &url,
 
      QStringList dirList;
 
-     m_home = new KDirMenu( parent, url.path(), QDir::homeDirPath() , text );
-     insertItem( SmallIcon( "kfm_home" ), i18n("&Home Directory"), m_home);
+     m_home = new KDirMenu( parent, url, QDir::homeDirPath() , text );
+     insertItem( SmallIcon( "kfm_home" ), i18n("&Home Folder"), m_home);
      dirList << QDir::homeDirPath();
 
-     m_root = new KDirMenu( parent, url.path(), QDir::rootDirPath() , text );
-     insertItem( SmallIcon( "folder_red" ), i18n("&Root Directory"), m_root);
+     m_root = new KDirMenu( parent, url, QDir::rootDirPath() , text );
+     insertItem( SmallIcon( "folder_red" ), i18n("&Root Folder"), m_root);
      dirList << QDir::rootDirPath();
 
      QString confDir = QDir::rootDirPath()+ "etc";
      if ( QFileInfo( confDir ).isWritable() )
      {
-         m_etc  = new KDirMenu( parent, url.path(), confDir, text );
+         m_etc  = new KDirMenu( parent, url, confDir, text );
          insertItem( SmallIcon( "folder_yellow" ) ,
                  i18n("&System Configuration"), m_etc);
          dirList << confDir;
@@ -65,14 +66,17 @@ KMetaMenu::KMetaMenu( QWidget *parent, const KURL &url,
 
      if ( url.isLocalFile()
              && dirList.find( url.path() ) == dirList.end()
-             && QFileInfo( url.path() ).isWritable() )
+             && QFileInfo( url.path() ).isWritable() 
+             && QFileInfo( url.path() ).isDir() )
+             //Need to check whether a directory so we don't crash trying to access it
+             //(#60192)
      {
          // Also add current working directory
-         m_current = new KDirMenu( parent, url.path(), url.path(), text );
-         insertItem( SmallIcon( "folder_blue" ), i18n( "&Current Directory" ),
+         m_current = new KDirMenu( parent, url, url.path(), text );
+         insertItem( SmallIcon( "folder_blue" ), i18n( "&Current Folder" ),
                  m_current );
 
-	 connect(m_current, SIGNAL(fileChosen(const QString &)),
+         connect(m_current, SIGNAL(fileChosen(const QString &)),
                  SLOT(slotFileChosen(const QString &) ) );
      }
 
@@ -88,7 +92,7 @@ KMetaMenu::KMetaMenu( QWidget *parent, const KURL &url,
      conf = kapp->config( );
      conf->setGroup(key );
      recent_no = conf->readNumEntry("ShowRecent", 5);
-     list = conf->readListEntry("Paths");
+     list = conf->readPathListEntry("Paths");
      if ( list.count() > 0 )
          insertSeparator();
      int i=1;
@@ -126,11 +130,11 @@ void KMetaMenu::writeConfig( const QString &path){
      list.remove(path );
      list.prepend(path );
      conf->setGroup( group );
-     conf->writeEntry("Paths",list );
+     conf->writePathEntry("Paths", list);
      conf->sync( );
 }
 void KMetaMenu::slotBrowse() {
-     QString dest = KFileDialog::getExistingDirectory();
+     KURL dest = KFileDialog::getExistingURL();
      if( dest.isEmpty() ) return;
-     slotFileChosen( dest );
+     slotFileChosen( dest.isLocalFile() ? dest.path() : dest.url() );
 }
