@@ -4,8 +4,8 @@
  *
  *  Copyright (C) 2001 by  Richard Moore <rich@kde.org>
  *                         Andreas Schlapbach <schlpbch@iam.unibe.ch>
- * 
- *  for information how to write your own plugin see:  
+ *
+ *  for information how to write your own plugin see:
  *    http://developer.kde.org/documentation/tutorials/dot/writing-plugins.html
  *
  *  This library is free software; you can redistribute it and/or
@@ -24,7 +24,7 @@
  *  Boston, MA 02111-1307, USA.
  **/
 
-/* $Id: plugin_validators.cpp,v 1.16.2.2 2003/07/18 00:59:45 mueller Exp $ */
+/* $Id: plugin_validators.cpp,v 1.21 2003/10/04 14:56:12 adawit Exp $ */
 
 #include <kinstance.h>
 #include <kmessagebox.h>
@@ -37,6 +37,7 @@
 #include "plugin_validators.h"
 #include "validatorsdialog.h"
 
+
 typedef KGenericFactory<PluginValidators> PluginValidatorsFactory;
 K_EXPORT_COMPONENT_FACTORY( libvalidatorsplugin,
 	                    PluginValidatorsFactory( "validatorsplugin" ) )
@@ -49,7 +50,7 @@ PluginValidators::PluginValidators( QObject* parent, const char* name,
 			     actionCollection(), "validateWebpage" );
   m_menu->setDelayed( false );
 
-  m_menu->insert( new KAction( i18n( "Validate &HTML" ), 
+  m_menu->insert( new KAction( i18n( "Validate &HTML" ),
 			       "htmlvalidator", 0,
 			       this, SLOT(slotValidateHTML()),
 			       actionCollection(), "validateHTML") );
@@ -57,7 +58,12 @@ PluginValidators::PluginValidators( QObject* parent, const char* name,
   m_menu->insert( new KAction( i18n( "Validate &CSS" ),
 			       "cssvalidator", 0,
 			       this, SLOT(slotValidateCSS()),
-			       actionCollection(), "validateCSS") );  
+			       actionCollection(), "validateCSS") );
+
+  m_menu->insert( new KAction( i18n( "Validate &Links" ),
+			       "linkvalidator", 0,
+			       this, SLOT(slotValidateLinks()),
+			       actionCollection(), "validateLinks") );
 
   m_menu->setEnabled( false );
 
@@ -96,6 +102,7 @@ void PluginValidators::setURLs()
   m_CSSValidatorUrl = KURL(m_configDialog->getCSSValidatorUrl());
   m_WWWValidatorUploadUrl = KURL(m_configDialog->getWWWValidatorUploadUrl());
   m_CSSValidatorUploadUrl = KURL(m_configDialog->getCSSValidatorUploadUrl());
+  m_linkValidatorUrl = KURL(m_configDialog->getLinkValidatorUrl());
 }
 
 void PluginValidators::slotStarted( KIO::Job* )
@@ -113,17 +120,22 @@ void PluginValidators::slotValidateHTML()
 
 void PluginValidators::slotValidateCSS()
 {
-  validateURL(m_CSSValidatorUrl, m_CSSValidatorUploadUrl);  
+  validateURL(m_CSSValidatorUrl, m_CSSValidatorUploadUrl);
+}
+
+void PluginValidators::slotValidateLinks()
+{
+  validateURL(m_linkValidatorUrl, KURL());
 }
 
 void PluginValidators::slotConfigure()
-{ 
+{
   m_configDialog->show();
   this->setURLs();
 }
 
 void PluginValidators::validateURL(const KURL &url, const KURL &uploadUrl)
-{ 
+{
   // The parent is assumed to be a KHTMLPart
   if ( !parent()->inherits("KHTMLPart") )
     {
@@ -139,7 +151,7 @@ void PluginValidators::validateURL(const KURL &url, const KURL &uploadUrl)
 
   // Get URL
   KURL partUrl = m_part->url();
-  if ( partUrl.isMalformed() ) // Just in case ;)
+  if ( !partUrl.isValid() ) // Just in case ;)
     {
       QString title = i18n( "Malformed URL" );
       QString text = i18n( "The URL you entered is not valid, please "
@@ -147,12 +159,19 @@ void PluginValidators::validateURL(const KURL &url, const KURL &uploadUrl)
       KMessageBox::sorry( 0, text, title );
       return;
     }
-  
-  if (partUrl.isLocalFile()) 
+
+  if (partUrl.isLocalFile())
     {
+      if ( validatorUrl.isEmpty() ) {
+        QString title = i18n( "Upload not possible" );
+        QString text = i18n( "Validating links is not possible for local "
+                             "files" );
+        KMessageBox::sorry( 0, text, title );
+        return;
+      }
       validatorUrl = uploadUrl;
-    } 
-  else 
+    }
+  else
     {
       if (partUrl.hasPass())
         {
