@@ -2,7 +2,7 @@
 //
 // C++ Implementation: dubplaylist.cpp
 //
-// Description: 
+// Description:
 //
 //
 // Author: Eray Ozkural (exa) <erayo@cs.bilkent.edu.tr>, (C) 2001
@@ -19,30 +19,39 @@
 #include <klocale.h>
 
 #include "dub.h"
+#include "dubconfigmodule.h"
 
 #include "dubplaylist.h"
 
+// plugin interface
+extern "C" Plugin *create_plugin()
+{
+  KGlobal::locale()->insertCatalogue("dub");
+  DubPlaylist* dub = new DubPlaylist;
+  return dub;
+}
+
 /** Construct playlist object */
 DubPlaylist::DubPlaylist()
  : Playlist(0, "Dub Playlist")
  , dub(0)
  , visible(false)
 {
-  kdDebug() << "cons DUB playlist" << endl;
+  kdDebug() << "dub: cons playlist" << endl;
 }
 
 DubPlaylist::~DubPlaylist(){
-  kdDebug() << "destruct DUB playlist " << endl;
+  kdDebug() << "dub: destruct playlist " << endl;
   // destroy app
   delete dub;
 }
 
 void DubPlaylist::reset() {
-  kdDebug() << "reset" << endl;
+  kdDebug() << "dub: reset" << endl;
 }
 
 void DubPlaylist::clear() {
-  kdDebug() << "reset" << endl;
+  kdDebug() << "dub: clear" << endl;
 }
 
 void DubPlaylist::addFile(const KURL&, bool play) {
@@ -58,22 +67,22 @@ PlaylistItem DubPlaylist::next() {
 
 PlaylistItem DubPlaylist::current() {
   if (!currentItem.isNull())
-    kdDebug() << "current item:" << currentItem.data()->url().prettyURL() << endl;
+    kdDebug() << "dub: current item:" << currentItem.data()->url().prettyURL() << endl;
   return currentItem;
 }
 
 PlaylistItem DubPlaylist::previous() {
-  kdDebug() << "previous" << endl;
+  kdDebug() << "dub: previous" << endl;
   dub->selectPreviousFile();
   updateCurrent();
   return currentItem;
 }
 
 PlaylistItem DubPlaylist::getFirst() const {
-  kdDebug() << "getFirst" << endl;
-  return 0;
+  kdDebug() << "dub: getFirst" << endl;
   const KFileItem* first = dub->queryFirstFile();
   if (first) {
+    kdDebug() << "dub: first " << first->url() << endl;
     DubPlaylistItem* firstData = new DubPlaylistItem(*first);
     return PlaylistItem(firstData);
   }
@@ -82,39 +91,37 @@ PlaylistItem DubPlaylist::getFirst() const {
 }
 
 PlaylistItem DubPlaylist::getAfter(const PlaylistItem &item) const {
-  kdDebug() << "getAfter" << endl;
+  kdDebug() << "dub: getAfter" << endl;
   return 0;
 }
 
 bool DubPlaylist::listVisible() const {
-  kdDebug() << "listVisible" << endl;
+  kdDebug() << "dub: listVisible" << endl;
   return visible;
 }
 
 void DubPlaylist::init() {
-  kdDebug() << "init" << endl;
-  dub = new DubApp(0, this);
-  kdDebug() << "init: test playlist() " << endl;
+  kdDebug() << "dub: init" << endl;
+  dubconfig = new DubConfigModule(this); // we pass this around to dub app
+  dub = new Dub(this);
+  kdDebug() << "dub: init: test playlist() " << endl;
   playlist();
-//  rootItem = DubPlaylistItem(dub->queryRoot());
-//  rootItem = DubPlaylistItem(&root);
 }
 
 void DubPlaylist::showList() {
-  kdDebug() << "showList" << endl;
+  kdDebug() << "dub: showList" << endl;
   visible = true;
   Q_ASSERT(dub);
   dub->show();
 }
 
 void DubPlaylist::hideList() {
-  kdDebug() << "hideList" << endl;
+  kdDebug() << "dub: hideList" << endl;
   visible = false;
   Q_ASSERT(dub);
   dub->hide();
 }
 
-
 //void DubPlaylist::remove(const PlaylistItem&) {
 //  KMessageBox::information(0, "Removing files not supported yet, see configuration");
 //}
@@ -124,7 +131,7 @@ void DubPlaylist::hideList() {
 //}
 
 Playlist* DubPlaylist::playlist() {
-  kdDebug() << "playlist pointer " << this << endl;
+  kdDebug() << "dub: playlist pointer " << this << endl;
   return static_cast<Playlist*>(this);
 }
 
