@@ -24,21 +24,21 @@
 DubPlaylistItem::DubPlaylistItem(const KFileItem& fItem)
  : fileItem(fItem)
 {
-  kdDebug() << "construct playlist item " << fItem.url().prettyURL() << endl;
+//   kdDebug() << "construct playlist item " << fItem.url().prettyURL() << endl;
 
 //  PlaylistItemData::addRef();
   PlaylistItemData::added();
 }
 
 DubPlaylistItem::~DubPlaylistItem(){
-  kdDebug() << "destruct playlist item " << fileItem.url().prettyURL() << endl;
+//   kdDebug() << "destruct playlist item " << fileItem.url().prettyURL() << endl;
 
 //  PlaylistItemData::removed();
   PlaylistItemData::removeRef();
 }
 
 QString DubPlaylistItem::property(const QString &key, const QString &def) const {
-  kdDebug() << "property " << key << endl;
+//   kdDebug() << "property " << key << endl;
   if (isProperty(key)) {
     kdDebug() << key << " -> " << property_map.find(key).data() << endl;
     return property_map.find(key).data();
@@ -48,17 +48,17 @@ QString DubPlaylistItem::property(const QString &key, const QString &def) const
 }
 
 void DubPlaylistItem::setProperty(const QString &key, const QString &val) {
-  kdDebug() << "set property" << endl;
+//   kdDebug() << "set property" << endl;
   property_map[key] = val;
 }
 
 void DubPlaylistItem::clearProperty(const QString &key) {
-  kdDebug() << "clear property" << endl;
+//   kdDebug() << "clear property" << endl;
   property_map.remove(key);
 }
 
 QStringList DubPlaylistItem::properties() const {
-  kdDebug() << "properties" << endl;
+//   kdDebug() << "properties" << endl;
   QStringList list;
   for (Properties::const_iterator i=property_map.begin();
        i!=property_map.end(); i++) {
@@ -68,16 +68,16 @@ QStringList DubPlaylistItem::properties() const {
 }
 
 bool DubPlaylistItem::isProperty(const QString &key) const {
-  kdDebug() << "is property? " << key << endl;
+//   kdDebug() << "is property? " << key << endl;
   return (property_map.find(key) != property_map.end());
 }
 
 KURL DubPlaylistItem::url() const {
-  kdDebug() << "item url" << endl;
+//   kdDebug() << "item url" << endl;
 
   return fileItem.url();
 }
 /** No descriptions */
 void DubPlaylistItem::remove() {
-  KMessageBox::information(0, i18n("Do you want to delete this file?"));
+  KMessageBox::information(0, i18n("Do you really want to delete this file?"));
 }
