@@ -41,7 +41,7 @@ Lyrics::Lyrics() : KMainWindow(), Plugin(), active(false)
   back_act->setEnabled(false);
   forward_act = KStdAction::forward(this, SLOT(forward()), actionCollection());
   forward_act->setEnabled(false);
-  new KWidgetAction( new QLabel(i18n("Search provider:"), this, "kde toolbar widget"), i18n("Search provider"), 0, 0, 0, actionCollection(), "search_label");
+  new KWidgetAction( new QLabel(i18n("Search provider:"), this, "kde toolbar widget"), i18n("Search Provider"), 0, 0, 0, actionCollection(), "search_label");
   site_act = new KSelectAction(i18n("&Search Provider"), 0, this, SLOT(viewLyrics()), actionCollection(), "search_provider");
 
   /* Add entry to menu */
@@ -73,7 +73,7 @@ Lyrics::Lyrics() : KMainWindow(), Plugin(), active(false)
   config->setGroup("Lyrics");
   follow_act->setChecked(config->readBoolEntry("follow", true));
   /* Create config object */
-  LyricsCModule *cmod = new LyricsCModule(this);
+  new LyricsCModule(this);
   
 }
 
@@ -251,6 +251,8 @@ Lyrics::~Lyrics()
 
 bool Lyrics::queryClose()
 {
+  if( kapp->sessionSaving())
+      return true;
 	hide();
   htmlpart->closeURL();
   htmlpart->begin();
