@@ -34,7 +34,7 @@ Input::Input()
 Input::~Input()
 {
 	delete mScope;
-	cerr<< "Scope gone"<<endl;
+	std::cerr<< "Scope gone"<< std::endl;
 	delete notifier;
 //	delete [] audio[2];
 //	delete [] audio[3];
@@ -83,7 +83,7 @@ void Input::getAudio(float **audio)
 		
 	if (!ok || !mScope->connected())
 	{
-		cerr << "reconnect" <<endl;
+		std::cerr << "reconnect" <<std::endl;
 		connect();
 		return;
 //		delete mScope;
@@ -91,11 +91,11 @@ void Input::getAudio(float **audio)
 //	    mScope=new StereoScope(10, Visualization::noatunPid());
 //	    mScope->setSamples(samples);
 	}
-	vector<float> *left, *right;
+	std::vector<float> *left, *right;
 	mScope->scopeData(left, right);
 	
-	register float *inleft=left->begin();
-	register float *inright=right->begin();
+	register float *inleft=&*left->begin();
+	register float *inright=&*right->begin();
 
 	
 	int offset=0;
