@@ -4,12 +4,13 @@
 #include <kprocess.h>
 #include <kmessagebox.h>
 #include <klocale.h>
-#include <kstddirs.h>
+#include <kstandarddirs.h>
 
 extern "C"
 {
 Plugin *create_plugin()
 {
+	KGlobal::locale()->insertCatalogue("nexscope");
 	return new NexPlugin();
 }
 }
@@ -33,7 +34,7 @@ void NexPlugin::init()
 	// for two separate checks.
 	if(!process.start(KProcess::NotifyOnExit, (KProcess::Communication)(KProcess::Stdin | KProcess::Stdout)))
 	{
-		KMessageBox::error(0, i18n("Could not start noatunNex.  Check your installation."));
+		KMessageBox::error(0, i18n("Unable to start noatunNex. Check your installation."));
 		unload();
 	}
 
