@@ -14,7 +14,7 @@
 
   You should have received a copy of the GNU General Public License along
   with this program; if not, write to the Free Software Foundation, Inc.,
-  675 Mass Ave, Cambridge, MA 02139, USA.
+  59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
 
 #ifndef SYNA_H
@@ -26,13 +26,13 @@
 #include <noatun/plugin.h>
 
 //**************************************
-//   For the incurably fiddle prone:   
+//   For the incurably fiddle prone:
 
 // log2 of sample size
-#define LogSize 9 
+#define LogSize 9
 
 // overlap amount between samples. Set to 1 or 2 if you have a fast computer
-#define Overlap 1 
+#define Overlap 1
 
 // Brightness
 #define Brightness 150
@@ -61,6 +61,9 @@ typedef unsigned short sampleType;
 #endif
 #ifdef HAVE_ENDIAN_H
 #include <endian.h>
+#elif defined(_BIG_ENDIAN) 
+#define BIG_ENDIAN 1 
+#define BYTE_ORDER BIG_ENDIAN 
 #endif
 typedef short sampleType;
 #endif
@@ -87,16 +90,17 @@ enum SymbolID
 	NotASymbol
 };
 
-// wrap 
+// wrap
 struct BaseScreen
 {
 	virtual bool init(int xHint, int yHint, int widthHint, int heightHint, bool fullscreen) = 0;
 	virtual void setPalette(unsigned char *palette) = 0;
 	virtual void end() = 0;
+	virtual void fullscreen()=0;
 	virtual int  sizeUpdate() = 0;
 	virtual bool inputUpdate(int &mouseX,int &mouseY,int &mouseButtons,char &keyHit) = 0;
 	virtual void show() = 0;
-	virtual void fullscreen()=0;
+	virtual void updateWindowCaption(const char *string)=0;
 };
 
 struct SdlScreen : public BaseScreen
@@ -108,7 +112,8 @@ struct SdlScreen : public BaseScreen
 	int  sizeUpdate();
 	bool inputUpdate(int &mouseX,int &mouseY,int &mouseButtons,char &keyHit);
 	void show();
-	int winID();
+//	int winID();
+	void updateWindowCaption(const char *string);
 };
 
 // core
@@ -138,16 +143,18 @@ public:
 	inline unsigned char *output() { return (unsigned char*)outputBmp.data; }
 	inline unsigned char *lastOutput() { return (unsigned char*)lastOutputBmp.data; }
 	inline unsigned char *lastLastOutput() { return (unsigned char*)lastLastOutputBmp.data; }
-	
+
 	void allocOutput(int w,int h);
 	void interfaceInit();
 	//void coreInit();
 	void setStarSize(double size);
 	void setupPalette(double);
-	
+
+	bool init ( void );
+
 	bool go();
 	bool calculate();
-	
+
 	void toDefaults();
 	void fade();
 	void fadeFade();
@@ -157,16 +164,16 @@ public:
 	void fadeHeat();
 
 	void fft(double*, double*);
-	
+
 	void addPixel(int x, int y, int br1, int br2);
 	void addPixelFast(unsigned char *p, int br1, int br2);
 	unsigned char getPixel(int x, int y, int where);
-	
+
 	static int bitReverser(int);
 
 protected:
 	void scopeEvent(float *, float *, int) {}
-	
+
 public:
 	BaseScreen *screen;
 	Interface *interface;
@@ -185,8 +192,8 @@ public:
 	SymbolID fadeMode;
 	bool pointsAreDiamonds;
 
-	double brightnessTwiddler; 
-	double starSize; 
+	double brightnessTwiddler;
+	double starSize;
 
 	double fgRedSlider, fgGreenSlider, bgRedSlider, bgGreenSlider;
 	SymbolID state;
@@ -202,7 +209,6 @@ inline unsigned char Core::getPixel(int x,int y,int where)
 	return lastOutput()[where];
 }
 
-
 struct Button;
 
 struct UIObject
@@ -229,13 +235,13 @@ public:
 	void setupPalette();
 
 	void putString(char *string,int x,int y,int red,int blue);
-	
+
 protected:
 	void addUI(UIObject *obj);
 	void changeState(int transitionSymbol);
-	
+
 private:
-	QPtrList<UIObject> uiObjects; 
+	QPtrList<UIObject> uiObjects;
 	Button *stateButton, *starsButton, *waveButton, *flameButton, *starButton, *diamondButton;
 	int mouseButtons;
 
@@ -244,6 +250,4 @@ private:
 
 };
 
-
-#endif 
-
+#endif
