@@ -13,9 +13,9 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
-/* $Id: wavecapture.cpp,v 1.10 2002/07/12 00:16:50 mhunter Exp $ */
+/* $Id: wavecapture.cpp,v 1.12 2003/10/04 14:56:12 adawit Exp $ */
 #include "wavecapture.h"
 
 #include <noatun/player.h>
@@ -138,7 +138,7 @@ void WaveCapture::saveAs()
 		if( dlg.exec() )
 		{
 			KURL url = dlg.selectedURL();
-			if (!url.isMalformed())
+			if (url.isValid())
 				KRecentDocument::add( url );
 
 			m_job = KIO::file_move( KURL( filename2 ), url, -1, true );
